@@ -17,8 +17,9 @@ from .actions import (
     NodejsNpmPackAction,
     NodejsNpmLockFileCleanUpAction,
     NodejsNpmInstallAction,
-    NodejsNpmrcCopyAction,
+    NodejsNpmrcAndLockfileCopyAction,
     NodejsNpmrcCleanUpAction,
+    NodejsNpmCIAction,
 )
 from .utils import OSUtils
 from .npm import SubprocessNpm
@@ -91,17 +92,21 @@ class NodejsNpmWorkflow(BaseWorkflow):
         npm_pack = NodejsNpmPackAction(
             tar_dest_dir, scratch_dir, manifest_path, osutils=osutils, subprocess_npm=subprocess_npm
         )
-        npm_copy_npmrc = NodejsNpmrcCopyAction(tar_package_dir, source_dir, osutils=osutils)
+
+        npm_copy_npmrc_and_lockfile = NodejsNpmrcAndLockfileCopyAction(tar_package_dir, source_dir, osutils=osutils)
 
         actions = [
             npm_pack,
-            npm_copy_npmrc,
+            npm_copy_npmrc_and_lockfile,
             CopySourceAction(tar_package_dir, artifacts_dir, excludes=self.EXCLUDED_FILES),
         ]
 
         if self.download_dependencies:
             # installed the dependencies into artifact folder
-            actions.append(NodejsNpmInstallAction(artifacts_dir, subprocess_npm=subprocess_npm))
+            install_action = NodejsNpmWorkflow.get_install_action(
+                source_dir, artifacts_dir, subprocess_npm, osutils, self.options
+            )
+            actions.append(install_action)
 
             # if dependencies folder exists, copy or move dependencies from artifact folder to dependencies folder
             # depends on the combine_dependencies flag
@@ -138,3 +143,41 @@ class NodejsNpmWorkflow(BaseWorkflow):
         specialized path resolver that just returns the list of executable for the runtime on the path.
         """
         return [PathResolver(runtime=self.runtime, binary="npm")]
+
+    @staticmethod
+    def get_install_action(source_dir, artifacts_dir, subprocess_npm, osutils, build_options, is_production=True):
+        """
+        Get the install action used to install dependencies at artifacts_dir
+
+        :type source_dir: str
+        :param source_dir: an existing (readable) directory containing source files
+
+        :type artifacts_dir: str
+        :param artifacts_dir: Dependencies will be installed in this directory.
+
+        :type osutils: aws_lambda_builders.workflows.nodejs_npm.utils.OSUtils
+        :param osutils: An instance of OS Utilities for file manipulation
+
+        :type subprocess_npm: aws_lambda_builders.workflows.nodejs_npm.npm.SubprocessNpm
+        :param subprocess_npm: An instance of the NPM process wrapper
+
+        :type build_options: Dict
+        :param build_options: Object containing build options configurations
+
+        :type is_production: bool
+        :param is_production: NPM installation mode is production (eg --production=false to force dev dependencies)
+
+        :rtype: BaseAction
+        :return: Install action to use
+        """
+        lockfile_path = osutils.joinpath(source_dir, "package-lock.json")
+        shrinkwrap_path = osutils.joinpath(source_dir, "npm-shrinkwrap.json")
+
+        npm_ci_option = False
+        if build_options and isinstance(build_options, dict):
+            npm_ci_option = build_options.get("use_npm_ci", False)
+
+        if (osutils.file_exists(lockfile_path) or osutils.file_exists(shrinkwrap_path)) and npm_ci_option:
+            return NodejsNpmCIAction(artifacts_dir, subprocess_npm=subprocess_npm)
+
+        return NodejsNpmInstallAction(artifacts_dir, subprocess_npm=subprocess_npm, is_production=is_production)
